@@ -315,9 +315,9 @@ const processedData = transformData(rawData, {
     ,(cadr minuet-default-fewshots)))
 
 (defvar minuet-claude-options
-  `(:model "claude-3-5-haiku-20241022"
+  `(:model "claude-haiku-4-5"
     :end-point "https://api.anthropic.com/v1/messages"
-    :max_tokens 512
+    :max_tokens 256
     :api-key "ANTHROPIC_API_KEY"
     :system
     (:template minuet-default-system-template
@@ -882,9 +882,23 @@ many lines.  Without a prefix argument, accept only the first line."
                             minuet--current-suggestions))
            (lines (split-string suggestion "\n"))
            (n (or n 1))
-           (selected-lines (seq-take lines n)))
+           (selected-lines (seq-take lines n))
+           (remaining-lines (seq-drop lines n))
+           (remaining-suggestion (when remaining-lines
+                                   (string-join remaining-lines "\n"))))
       (minuet--cleanup-suggestion)
-      (insert (string-join selected-lines "\n")))))
+      (insert (string-join selected-lines "\n"))
+      (if remaining-suggestion
+          (progn
+            (insert "\n") ;; There is a remaining suggestion, so move to the next line.
+            ;; NOTE: We do not need to worry about Minuet
+            ;; automatically triggering the next suggestion upon
+            ;; continuous acceptance.  Minuet only attempts
+            ;; auto-suggestion when the last command was not a Minuet
+            ;; command. Since we have just accepted partial lines, the
+            ;; last command is indeed a Minuet command.
+            (minuet--display-suggestion (list remaining-suggestion) 0))
+        (minuet--cleanup-suggestion)))))
 
 ;;;###autoload
 (defun minuet-complete-with-minibuffer ()
@@ -1391,14 +1405,9 @@ settings, as an alternative to manual configuration via `setq' and
 `openai-fim-compatible' providers, users will be prompted to specify
 their endpoint and API key."
   (interactive)
-  (let* ((providers '(("OpenAI" . openai)
-                      ("Claude" . claude)
-                      ("Codestral" . codestral)
-                      ("OpenAI Compatible" . openai-compatible)
-                      ("OpenAI FIM Compatible" . openai-fim-compatible)
-                      ("Gemini" . gemini)))
+  (let* ((providers (mapcar #'cddr (cdr (get 'minuet-provider 'custom-type))))
          (provider-name (completing-read "Select provider: " providers nil t))
-         (provider (alist-get provider-name providers nil nil #'equal))
+         (provider (car (alist-get provider-name providers nil nil #'equal)))
          (options-sym (intern (format "minuet-%s-options" provider)))
          (options (symbol-value options-sym))
          (current-model (plist-get options :model))
